<?php defined('SYSPATH') OR die('No direct access allowed.');
/**
 * Traps controller
 *
 *  op5, and the op5 logo are trademarks, servicemarks, registered servicemarks
 *  or registered trademarks of op5 AB.
 *  All other trademarks, servicemarks, registered trademarks, and registered
 *  servicemarks mentioned herein may be the property of their respective owner(s).
 *  The information contained herein is provided AS IS with NO WARRANTY OF ANY
 *  KIND, INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY, AND FITNESS FOR A
 *  PARTICULAR PURPOSE.
 */
class Traps_Controller extends Authenticated_Controller
{
	private function show_traps($problems_only, $host)
	{
		$auth = new Nagios_auth_Model();
		if (!$auth->view_hosts_root) {
			$this->template->content = $this->add_view('unauthorized');
			$this->template->content->error_message = _('It appears as though you do not have permission to view information you requested...');
			$this->template->content->error_description = _('If you believe this is an error, check the HTTP server authentication requirements for accessing this page
			and check the authorization options in your CGI configuration file.');
			return;
		}
		$this->template->content = $this->add_view('traps/index');
		$this->template->js_header = $this->add_view('js_header');
		$content = $this->template->content;
		$traps = new Traps_Model();
		$content->sortby = isset($_GET['sortby']) ? $_GET['sortby'] : 'time';
		$content->order = isset($_GET['order']) ? $_GET['order'] : 'desc';
		$content->problems_only = $problems_only;
		$traps_data = $traps->fetch_traps_data($problems_only, $host, $content->sortby, $content->order);
		$content->labels = array(
			'time'    => _('Time'),
			'host'    => _('Host'),
			'service' => _('Service'),
			'tag'     => _('Tag'),
			'state'   => _('State'),
			'count'   => _('Count'),
			'trapoid' => _('OID'),
			'message' => _('Message'),
			'trap'    => _('Raw Data'),
			'actions' => _('Actions')
		);
		$content->traps_data = $traps_data;
		$logs = new Traps_Logs_Model();
		$content->logs_number = $logs->how_many();
		$content->title = _('SNMP Traps');
		$this->template->title = _('Monitoring » SNMP Traps');
		# date::timespan(time(), $result->last_update, 'days,hours,minutes,seconds');
	}

	/**
	*	@name	index
	*	@desc	default method
	*
	*/
	public function index()
	{
		$this->show_traps(false, null);
	}

	/**
	*	shows traps that caused service/tag state changes
	*/
	public function all($host = null)
	{
		$this->show_traps(false, $host);
	}

	/**
	*	shows traps that caused service/tag state changes to WARNING/CRITICAL
	*/
	public function problems($host = null)
	{
		$this->show_traps(true, $host);
	}

	/**
	*	removes a trap from the table
	*/
	public function delete()
	{
		$auth = new Nagios_auth_Model();
		if (!$auth->view_hosts_root)
			return;

		$traps = new Traps_Model();
		$traps->delete_trap($_GET["host"], $_GET["service"], $_GET["tag"]);
		$this->auto_render=false;
	}

	/**
	*	changes trap's state
	*/
	public function change_state()
	{
		$auth = new Nagios_auth_Model();
		if (!$auth->view_hosts_root)
			return;

		$traps = new Traps_Model();
		$traps->change_state($_GET["host"], $_GET["service"], $_GET["tag"], $_GET["state"]);
		$this->auto_render=false;
	}

	/**
	*	marks problem trap as acknowledged
	*/
	public function acknowledge()
	{
		$auth = new Nagios_auth_Model();
		if (!$auth->view_hosts_root)
			return;

		$traps = new Traps_Model();
		$traps->acknowledge($_GET["host"], $_GET["service"], $_GET["tag"]);
		$this->auto_render=false;
	}

	/**
	*	shows error logs
	*/
	public function logs()
	{
		$auth = new Nagios_auth_Model();
		if (!$auth->view_hosts_root) {
			$this->template->content = $this->add_view('unauthorized');
			$this->template->content->error_message = _('It appears as though you do not have permission to view information you requested...');
			$this->template->content->error_description = _('If you believe this is an error, check the HTTP server authentication requirements for accessing this page
			and check the authorization options in your CGI configuration file.');
			return;
		}
		$this->template->content = $this->add_view('traps/logs');
		$this->template->js_header = $this->add_view('js_header');
		$content = $this->template->content;
		$logs = new Traps_Logs_Model();
		$content->sortby = isset($_GET['sortby']) ? $_GET['sortby'] : 'id';
		$content->order = isset($_GET['order']) ? $_GET['order'] : 'desc';
		$messages = $logs->fetch_messages($content->sortby, $content->order);
		$content->labels = array(
			'id'      => _('ID'),
			'time'    => _('Time'),
			'handler' => _('Handler'),
			'message' => _('Message'),
			'actions' => _('Actions')
		);
		$content->logs = $messages;
		$content->title = _('Logs');
		$this->template->title = _('Monitoring » SNMP Traps » Logs');
		# date::timespan(time(), $result->last_update, 'days,hours,minutes,seconds');
	}

	/**
	*	removes a message from the logs
	*/
	public function delete_message($id)
	{
		$auth = new Nagios_auth_Model();
		if (!$auth->view_hosts_root)
			return;

		$traps = new Traps_Logs_Model();
		$traps->delete_message($id);
		$this->auto_render=false;
	}
}
